pub struct MailSendResponse {
pub message_id: MessageId,
pub from: Address,
}Expand description
Re-export common wire types so hatchery can use mail4agent_client::*.
Answers a SendRequest. Returns the caller its own address so a
participant that just wrote immediately knows where it can be answered.
Fields
message_id: MessageIdfrom: AddressImplementations